use async_std::io::BufReader;
use async_std::os::unix::net::UnixStream;
use std::boxed::Box;
use std::error::Error;

pub async fn handle_incoming(stream: UnixStream) -> Result<(), Box<dyn Error>> {
    let mut reader = BufReader::new(stream);

    let res = protocol::read_from_stream(&mut reader).await?;
    let init: protocol::Init = bincode::deserialize(&res)?;
    log::info!(
        "Incoming connection from {} version: {}",
        init.name,
        init.version
    );

    let res = protocol::Init {
        name: env!("CARGO_PKG_NAME"),
        version: env!("CARGO_PKG_VERSION"),
    };

    protocol::write_to_stream(&mut reader, res).await?;
    log::info!("Connected");

    // TODO: actually handle all the interconnection stuff
    // TODO: graceful shutdown

    Ok(())
}
