use async_std::io;
use async_std::os::unix::net::UnixListener;
use async_std::stream::StreamExt;
use env_logger::Builder;
use log::LevelFilter;

mod handler;

#[async_std::main]
async fn main() -> io::Result<()> {
    Builder::from_default_env()
        .filter(None, LevelFilter::Info)
        .init();

    let listener = UnixListener::bind("/tmp/bbs_frontend.sck").await?;
    let mut incoming = listener.incoming();

    while let Some(stream) = incoming.next().await {
        if let Err(e) = handler::handle_incoming(stream?).await {
            log::error!("Error handling incoming connection: {}", e);
        }
    }

    Ok(())
}
