use async_std::io::{self, BufReader};
use async_std::os::unix::net::UnixStream;
use env_logger::Builder;
use log::LevelFilter;

#[async_std::main]
async fn main() -> io::Result<()> {
    Builder::from_default_env()
        .filter(None, LevelFilter::Info)
        .init();

    let stream = UnixStream::connect("/tmp/bbs_frontend.sck").await.unwrap();
    let mut reader = BufReader::new(stream);

    let init = protocol::Init {
        name: env!("CARGO_PKG_NAME"),
        version: env!("CARGO_PKG_VERSION"),
    };
    log::info!(
        "Connecting to backend ({} version: {})",
        init.name,
        init.version
    );

    protocol::write_to_stream(&mut reader, init).await?;
    let res = protocol::read_from_stream(&mut reader).await?;
    let res: protocol::Init = bincode::deserialize(&res).unwrap();

    log::info!("Connected to {} version: {}", res.name, res.version);

    Ok(())
}
