use async_std::io::prelude::BufReadExt;
use async_std::io::{self, WriteExt, BufReader};
use async_std::os::unix::net::UnixStream;
use serde::{Serialize, Deserialize};

pub mod response;
pub mod request;

#[derive(Serialize, Deserialize)]
pub struct Init<'a> {
    pub name: &'a str,
    pub version: &'a str,
}

pub async fn write_to_stream<T: Serialize>(reader: &mut BufReader<UnixStream>, msg: T) -> io::Result<()> {
    let mut buf = bincode::serialize(&msg).unwrap();
    buf.push(b'\n');
    reader.get_mut().write(&buf).await?;

    Ok(())
} 

pub async fn read_from_stream(reader: &mut BufReader<UnixStream>) -> io::Result<Vec<u8>> {
    let mut buf = Vec::new();
    reader.read_until(b'\n', &mut buf).await?;

    Ok(buf)
}
